====
TODO
====
  
  Things that would be great to have but we haven't gotten to do them yet

Code
----
* Cleanup of helpers, forms and models would be great
  
* There are no unit tests

* Working ``--profile`` instead of the old school environment variable

* No examples in the code

Docs
----
* Helpers are not mentioned in the docs

* Forms and models are only by means of API, no proper introduction

* There is no clear roadmap of where this project is heading

* No FAQ, Tutorial

Community
---------
* There is no ``README.rst`` file for `GitHub <http://www.github.com/>`_ needs

* There is no ``long_description`` for `PyPI <http://pypi.python.org/>`_

* There is no community

* Some publicity would be helpful
